==> k3d_0.4.3.0.orig.tar.gz: k3d-0.4.3.0/k3dsdk/bitmap_source.h <==
#ifndef K3DSDK_BITMAP_SOURCE_H
#define K3DSDK_BITMAP_SOURCE_H

// K-3D
// Copyright (c) 1995-2004, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include "ibitmap_source.h"
#include "bitmap.h"
#include "property_collection.h"
#include "selection.h"

namespace k3d
{

template<typename base_t>
class bitmap_source :
	public base_t,
	public ibitmap_source
{
public:
	bitmap_source(idocument& Document) :
		base_t(Document),
		m_output(init_name("output") + init_description("Output bitmap [bitmap]") + init_document(Document))
	{
		base_t::register_property(m_output);
	}

	iproperty& bitmap_source_output()
	{
		return m_output;
	}

protected:
	k3d_read_only_data_property(bitmap*, immutable_name, change_signal, no_undo, demand_storage, no_constraint) m_output;
};

} // namespace k3d

#endif // !K3DSDK_BITMAP_SOURCE_H

==> k3d_0.5.0.35.orig.tar.gz: k3d-0.5.0.35/k3dsdk/bitmap_source.h <==
#ifndef K3DSDK_BITMAP_SOURCE_H
#define K3DSDK_BITMAP_SOURCE_H

// K-3D
// Copyright (c) 1995-2004, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include "data.h"
#include "i18n.h"
#include "ibitmap_source.h"
#include "bitmap.h"
#include "selection.h"

namespace k3d
{

template<typename base_t>
class bitmap_source :
	public base_t,
	public ibitmap_source
{
public:
	bitmap_source(idocument& Document) :
		base_t(Document),
		m_output(init_owner(*this) + init_name("output") + init_label(_("Output Bitmap")) + init_description(_("Output bitmap")))
	{
	}

	iproperty& bitmap_source_output()
	{
		return m_output;
	}

protected:
	k3d_data(bitmap*, immutable_name, change_signal, no_undo, demand_storage, no_constraint, read_only_property, no_serialization) m_output;
};

} // namespace k3d

#endif // !K3DSDK_BITMAP_SOURCE_H
